We have joined forces with other data technologists to deliver the most
thorough and integrated frameworks and solutions to you.

## Databricks
The [Databricks](http://www.databricks.com) Platform is the world's first data
intelligence platform powered by generative AI.
<img src="/images/okube_databricks.png" alt="okube-databricks" width="600"/>

Unleash the full potential of Laktory pipelines by orchestrating them on 
Databricks Delta Live Tables or Jobs. 

Laktory also helps you deploy and operate a Dataricks lakehouse with support
for all main components, from users management to Unity Catalog grants 
and including jobs scheduling.
